@@ -46,6 +46,59 @@ def add_images_to_existing_project(session, projnumber):
         for template in task_templates:
             if template["name"] == "Image_Template":
                 image_template = template
+            if template["name"] == "MovingImage_Template":
+                moving_image_template = template
+
+        while True:
+            try:
+                additional_ints = int(input("Enter amount of additional INT images: "))
+            except ValueError:
+                print("Sorry, I didn't understand that? Did you type a number?")
+                continue
+            else:
+                print(f"Number of addtional INT:{additional_ints}")
+                break
+
+        if additional_ints > 0:
+            if len(project_team) > 1:
+                int_artist = select_artist(project_team, users, "Select INT artist")
+            else:
+                int_artist = project_team[0]
+
+        while True:
+            try:
+                additional_exteriors = int(
+                    input("Enter amount of additional EXT images: "))
+            except ValueError:
+                print("Sorry, I didn't understand that? Did you type a number?")
+                continue
+            else:
+                print(f"Number of addtional EXT: {additional_exteriors}")
+                break
+
+        if additional_exteriors > 0:
+            if len(project_team) > 1:
+                ext_artist = select_artist(project_team, users, "Select EXT artist")
+            else:
+                ext_artist = project_team[0]
+
+        while True:
+            try:
+                additional_moving = int(
+                    input("Enter amount of additional MovingImage images: "))
+            except ValueError:
+                print("Sorry, I didn't understand that? Did you type a number?")
+                continue
+            else:
+                print(f"Number of addtional MovingImage: {additional_moving}")
+                break
+
+        if additional_moving > 0:
+            if len(project_team) > 1:
+                moving_artist = select_artist(
+                    project_team, users, "Select MovingImage artist")
+            else:
+                moving_artist = project_team[0]
 
         interior_shots = [i for i in existing_project['children'] if "INT" in i["name"]]
         num_exist_int = 0
@@ -98,56 +151,6 @@ def add_images_to_existing_project(session, projnumber):
                     "parent": existing_project
                 })
 
-        while True:
-            try:
-                additional_ints = int(input("Enter amount of additional INT shots: "))
-            except ValueError:
-                print("Sorry, I didn't understand that? Did you type a number?")
-                continue
-            else:
-                print(f"Number of addtional INT:{additional_ints}")
-                break
-
-        if additional_ints > 0:
-            if len(project_team) > 1:
-                int_artist = select_artist(project_team, users, "Select INT artist")
-            else:
-                int_artist = project_team[0]
-
-        while True:
-            try:
-                additional_exteriors = int(
-                    input("Enter amount of additional EXT shots: "))
-            except ValueError:
-                print("Sorry, I didn't understand that? Did you type a number?")
-                continue
-            else:
-                print(f"Number of addtional EXT:{additional_exteriors}")
-                break
-
-        if additional_exteriors > 0:
-            if len(project_team) > 1:
-                ext_artist = select_artist(project_team, users, "Select EXT artist")
-            else:
-                ext_artist = project_team[0]
-
-        while True:
-            try:
-                additional_moving = int(
-                    input("Enter amount of additional MovingImage shots: "))
-            except ValueError:
-                print("Sorry, I didn't understand that? Did you type a number?")
-                continue
-            else:
-                print(f"Number of addtional MovingImage: {additional_moving}")
-                break
-
-        if additional_moving > 0:
-            if len(project_team) > 1:
-                moving_artist = select_artist(
-                    project_team, users, "Select MovingImage artist")
-            else:
-                moving_artist = project_team[0]
         # interiors
         num_int = num_exist_int + additional_ints
         for i in range(num_exist_int, num_exist_int + additional_ints):
@@ -201,7 +204,7 @@ def add_images_to_existing_project(session, projnumber):
                 "name": moving_shot_name,
                 "parent": moving_folder}
             )
-            for task_type in [t["task_type"] for t in image_template["items"]]:
+            for task_type in [t["task_type"] for t in moving_image_template["items"]]:
                 task = session.create("Task", {
                                       "name": task_type["name"],
                                       "type": task_type,
