@@ -332,7 +332,6 @@ def create_new_project(session):
                 },
             )
             for task_type in [t["task_type"] for t in moving_image_template["items"]]:
-                print(task_type)
                 task = session.create(
                     "Task",
                     {
@@ -353,6 +352,8 @@ def create_new_project(session):
         project_set.add(int_artist)
     if num_ext > 0:
         project_set.add(ext_artist)
+    if num_moving > 0:
+        project_set.add(movingImage_artist)
 
     if internal_project:
         for artist in project_set:
@@ -383,7 +384,6 @@ def create_new_project(session):
     if deal is not None:
         print(f"Based on deal {deal}")
     print(f"--- creating objects for {project_name} on ftrack")
-    # print(f"--- creating outlook folder for {project_name}")
     print(f"--- creating directory for {project_name} on X:/")
     create_project_on_fileserver(project_name, internal_project, deal)
     print(
@@ -393,7 +393,7 @@ def create_new_project(session):
         f"-- {num_ext} EXT tasks for {ext_artist['username']}"
     ) if num_ext > 0 else None
     print(
-        f"-- {num_moving} EXT tasks for {movingImage_artist['username']}"
+        f"-- {num_moving} MovingImage tasks for {movingImage_artist['username']}"
     ) if num_moving > 0 else None
     print("--- creating photography tasks") if drone else None
     print(f"--- creating {project_name}.mxp for 3dsmax project")
